@@ -1,14 +1,14 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-
 import os
 import sys
+import threading
 from pathlib import Path
 
 from loguru import logger
 
 # Component version
-__version__ = "2.1.0"
+__version__ = "3.0.0"
 
 # Get component full version from file generated at build time
 current_file_dir = Path(__file__).resolve().parent
@@ -28,3 +28,5 @@ config = {
     ],
 }
 logger.configure(**config)
+
+shutil_make_archive_lock = threading.Lock()
