@@ -34,13 +34,8 @@ import requests
 from loguru import logger
 
 import cr_api_client.core_api as core_api
-
-
-# Configuration access to Cyber Range endpoint
-PROVISIONING_API_URL = "http://127.0.0.1:5003"
-CA_CERT_PATH = None  # Expect a path to CA certs (see: https://requests.readthedocs.io/en/master/user/advanced/)
-CLIENT_CERT_PATH = None  # Expect a path to client cert (see: https://requests.readthedocs.io/en/master/user/advanced/)
-CLIENT_KEY_PATH = None  # Expect a path to client private key (see: https://requests.readthedocs.io/en/master/user/advanced/)
+from cr_api_client import shutil_make_archive_lock
+from cr_api_client.config import cr_api_client_config
 
 
 # -------------------------------------------------------------------------- #
@@ -50,36 +45,36 @@ CLIENT_KEY_PATH = None  # Expect a path to client private key (see: https://requ
 
 def _get(route: str, **kwargs: str) -> Any:
     return requests.get(
-        f"{PROVISIONING_API_URL}{route}",
-        verify=CA_CERT_PATH,
-        cert=(CLIENT_CERT_PATH, CLIENT_KEY_PATH),
+        f"{cr_api_client_config.provisioning_api_url}{route}",
+        verify=cr_api_client_config.cacert,
+        cert=(cr_api_client_config.cert, cr_api_client_config.key),
         **kwargs,
     )
 
 
 def _post(route: str, **kwargs: str) -> Any:
     return requests.post(
-        f"{PROVISIONING_API_URL}{route}",
-        verify=CA_CERT_PATH,
-        cert=(CLIENT_CERT_PATH, CLIENT_KEY_PATH),
+        f"{cr_api_client_config.provisioning_api_url}{route}",
+        verify=cr_api_client_config.cacert,
+        cert=(cr_api_client_config.cert, cr_api_client_config.key),
         **kwargs,
     )
 
 
 def _put(route: str, **kwargs: str) -> Any:
     return requests.put(
-        f"{PROVISIONING_API_URL}{route}",
-        verify=CA_CERT_PATH,
-        cert=(CLIENT_CERT_PATH, CLIENT_KEY_PATH),
+        f"{cr_api_client_config.provisioning_api_url}{route}",
+        verify=cr_api_client_config.cacert,
+        cert=(cr_api_client_config.cert, cr_api_client_config.key),
         **kwargs,
     )
 
 
 def _delete(route: str, **kwargs: str) -> Any:
     return requests.delete(
-        f"{PROVISIONING_API_URL}{route}",
-        verify=CA_CERT_PATH,
-        cert=(CLIENT_CERT_PATH, CLIENT_KEY_PATH),
+        f"{cr_api_client_config.provisioning_api_url}{route}",
+        verify=cr_api_client_config.cacert,
+        cert=(cr_api_client_config.cert, cr_api_client_config.key),
         **kwargs,
     )
 
@@ -118,7 +113,8 @@ def _zip_resources(resources_path: str, temp_dir: str) -> str:
     """Private function to zip resources path content"""
     zip_file_name = os.path.join(temp_dir, "resources")
 
-    shutil.make_archive(zip_file_name, "zip", resources_path)
+    with shutil_make_archive_lock:
+        shutil.make_archive(zip_file_name, "zip", resources_path)
 
     return "{}.zip".format(zip_file_name)
 
@@ -246,6 +242,7 @@ def provisioning_ansible(
     target_system_types: List[str] = [],
     target_operating_systems: List[str] = [],
     target_names: List[str] = [],
+    host_vars: List[str] = [],
     extra_vars: str = None,
     debug: bool = False,
     wait: bool = True,
@@ -302,10 +299,11 @@ def provisioning_ansible(
         "target_system_types": target_system_types,
         "target_operating_systems": target_operating_systems,
         "target_names": target_names,
+        "host_vars": host_vars,
         "debug": debug,
     }
 
-    with TemporaryDirectory() as temp_dir:
+    with TemporaryDirectory(prefix="cyber_range_cr_provisioning_archive") as temp_dir:
         # Zipping resource files
         zip_file_name = _zip_resources(playbook_path, temp_dir)
         resources_file = open(zip_file_name, "rb")
@@ -526,13 +524,12 @@ def provisioning_wait_until_complete(
 def __wait_for_the_operation_to_start(task_id: str) -> bool:
 
     running = False
-    timeout = 5
+    timeout = 10
     start_time = time.time()
     while not (running or (time.time() - start_time) > timeout):
         result = _post("/provisioning/status_provisioning", data={"task_id": task_id})
         result.raise_for_status()
         result = result.json()
-        print(result)
         running = result["status"] == "RUNNING"
         time.sleep(1)
 
@@ -568,17 +565,10 @@ def __handle_wait(
         if not success:
             _raise_error_msg(result)
 
-    else:
-        # wait for the operation to start
-        running = __wait_for_the_operation_to_start(task_id)
-
-        if not running:
-            success = False
-
     return success
 
 
-def provisioning_report():
+def provisioning_report() -> dict:
     """Get ansible report from backend"""
 
     result = _post("/provisioning/report_provisioning", data={})
